Export Package VRC : bcB40Pc4ca20
Update compared VRC:   B40 c4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
tbcstf000                           B40Pc4ca20
tbcstf013                           B40Pc4ca20
tbcsts007                           B40Pc4ca20
tbcswh007                           B40Pc4ca20
sbcstf0100m000                      B40Pc4ca20
sbcstf0109m000                      B40Pc4ca20
sbcstf0113m000                      B40Pc4ca20
sbcsts0105m000                      B40Pc4ca20
sbcsts0107m000                      B40Pc4ca20
pbcdllfbcttf006                     B40Pc4ca20 (without source)
pbcdllfcisli100                     B40Pc4ca20 (without source)
pbcdllfcisli120                     B40Pc4ca20 (without source)
pbcdllfcisli200                     B40Pc4ca20 (without source)
pbcdllfcisli201                     B40Pc4ca20 (without source)
pbcdllfcprpd400                     B40Pc4ca20 (without source)
pbcdllfcprpd420                     B40Pc4ca20 (without source)
pbcdllfecedi702                     B40Pc4ca20 (without source)
pbcdllffmfmd100                     B40Pc4ca20 (without source)
pbcdllffmfrc000                     B40Pc4ca20 (without source)
pbcdllffmlbd000                     B40Pc4ca20 (without source)
pbcdllfqmptc101                     B40Pc4ca20 (without source)
pbcdllfqmptc110                     B40Pc4ca20 (without source)
pbcdllfqmptc115                     B40Pc4ca20 (without source)
pbcdllfqmptc230                     B40Pc4ca20 (without source)
pbcdllfqmptc301                     B40Pc4ca20 (without source)
pbcdllfqmptc302                     B40Pc4ca20 (without source)
pbcdllfqmptc305                     B40Pc4ca20 (without source)
pbcdllftccom000                     B40Pc4ca20 (without source)
pbcdllftccom700                     B40Pc4ca20 (without source)
pbcdllftccom710                     B40Pc4ca20 (without source)
pbcdllftccom999                     B40Pc4ca20 (without source)
pbcdllftcemm000                     B40Pc4ca20 (without source)
pbcdllftcmcs000                     B40Pc4ca20 (without source)
pbcdllftcmcs001                     B40Pc4ca20 (without source)
pbcdllftcmcs055                     B40Pc4ca20 (without source)
pbcdllftcmcs120                     B40Pc4ca20 (without source)
pbcdllftcmcs121                     B40Pc4ca20 (without source)
pbcdllftcmcs122                     B40Pc4ca20 (without source)
pbcdllftcmcs123                     B40Pc4ca20 (without source)
pbcdllftcmcs138                     B40Pc4ca20 (without source)
pbcdllftctax000                     B40Pc4ca20 (without source)
pbcdllftctax601                     B40Pc4ca20 (without source)
pbcdllftctax603                     B40Pc4ca20 (without source)
pbcdllftdipu010                     B40Pc4ca20 (without source)
pbcdllftdpcg000                     B40Pc4ca20 (without source)
pbcdllftdpur000                     B40Pc4ca20 (without source)
pbcdllftdpur012                     B40Pc4ca20 (without source)
pbcdllftdpur400                     B40Pc4ca20 (without source)
pbcdllftdpur451                     B40Pc4ca20 (without source)
pbcdllftdsls000                     B40Pc4ca20 (without source)
pbcdllftdsls012                     B40Pc4ca20 (without source)
pbcdllftdsls027                     B40Pc4ca20 (without source)
pbcdllftdsls028                     B40Pc4ca20 (without source)
pbcdllftdsls060                     B40Pc4ca20 (without source)
pbcdllftdsls094                     B40Pc4ca20 (without source)
pbcdllftdsls301                     B40Pc4ca20 (without source)
pbcdllftdsls351                     B40Pc4ca20 (without source)
pbcdllftdsls400                     B40Pc4ca20 (without source)
pbcdllftdsls450                     B40Pc4ca20 (without source)
pbcdllftdsls451                     B40Pc4ca20 (without source)
pbcdllftdsmi002                     B40Pc4ca20 (without source)
pbcdllftdsmi003                     B40Pc4ca20 (without source)
pbcdllftdsmi040                     B40Pc4ca20 (without source)
pbcdllftdsmi054                     B40Pc4ca20 (without source)
pbcdllftdsmi101                     B40Pc4ca20 (without source)
pbcdllftdsmi110                     B40Pc4ca20 (without source)
pbcdllftdsmi111                     B40Pc4ca20 (without source)
pbcdllftdsmi121                     B40Pc4ca20 (without source)
pbcdllftdsmi201                     B40Pc4ca20 (without source)
pbcdllftdsmi206                     B40Pc4ca20 (without source)
pbcdllftdsmi210                     B40Pc4ca20 (without source)
pbcdllftfacp002                     B40Pc4ca20 (without source)
pbcdllftfacp200                     B40Pc4ca20 (without source)
pbcdllftfacr200                     B40Pc4ca20 (without source)
pbcdllftfcmg000                     B40Pc4ca20 (without source)
pbcdllftfcmg006                     B40Pc4ca20 (without source)
pbcdllftffam000                     B40Pc4ca20 (without source)
pbcdllftffam010                     B40Pc4ca20 (without source)
pbcdllftffam100                     B40Pc4ca20 (without source)
pbcdllftffam110                     B40Pc4ca20 (without source)
pbcdllftffam200                     B40Pc4ca20 (without source)
pbcdllftffam520                     B40Pc4ca20 (without source)
pbcdllftffam650                     B40Pc4ca20 (without source)
pbcdllftffam710                     B40Pc4ca20 (without source)
pbcdllftffam775                     B40Pc4ca20 (without source)
pbcdllftffst011                     B40Pc4ca20 (without source)
pbcdllftfgld004                     B40Pc4ca20 (without source)
pbcdllftfgld107                     B40Pc4ca20 (without source)
pbcdllftfgld110                     B40Pc4ca20 (without source)
pbcdllftiedm000                     B40Pc4ca20 (without source)
pbcdllftiedm010                     B40Pc4ca20 (without source)
pbcdllftiedm120                     B40Pc4ca20 (without source)
pbcdllftipcf000                     B40Pc4ca20 (without source)
pbcdllftipcf320                     B40Pc4ca20 (without source)
pbcdllftipcs030                     B40Pc4ca20 (without source)
pbcdllftipcs400                     B40Pc4ca20 (without source)
pbcdllftipcs420                     B40Pc4ca20 (without source)
pbcdllftirou000                     B40Pc4ca20 (without source)
pbcdllftirou102                     B40Pc4ca20 (without source)
pbcdllftisfc000                     B40Pc4ca20 (without source)
pbcdllftisfc001                     B40Pc4ca20 (without source)
pbcdllftisfc010                     B40Pc4ca20 (without source)
pbcdllftppdm600                     B40Pc4ca20 (without source)
pbcdllftpppc000                     B40Pc4ca20 (without source)
pbcdllftpppc210                     B40Pc4ca20 (without source)
pbcdllftppss200                     B40Pc4ca20 (without source)
pbcdllftscfg210                     B40Pc4ca20 (without source)
pbcdllftsctm100                     B40Pc4ca20 (without source)
pbcdllftsctm110                     B40Pc4ca20 (without source)
pbcdllftsctm400                     B40Pc4ca20 (without source)
pbcdllfwhinh000                     B40Pc4ca20 (without source)
pbcdllfwhinh010                     B40Pc4ca20 (without source)
pbcdllfwhinr130                     B40Pc4ca20 (without source)
pbcdllfwhwmd000                     B40Pc4ca20 (without source)
pbcdllmcisli205                     B40Pc4ca20 (without source)
pbcdllmcisli220                     B40Pc4ca20 (without source)
pbcdllmcisli230                     B40Pc4ca20 (without source)
pbcdllmcisli240                     B40Pc4ca20 (without source)
pbcdllmcisli250                     B40Pc4ca20 (without source)
pbcdllmcisli260                     B40Pc4ca20 (without source)
pbcdllmcprpd100                     B40Pc4ca20 (without source)
pbcdllmcprrp100                     B40Pc4ca20 (without source)
pbcdllmfmfoc200                     B40Pc4ca20 (without source)
pbcdllmqmptc100                     B40Pc4ca20 (without source)
pbcdllmtccom100                     B40Pc4ca20 (without source)
pbcdllmtccom140                     B40Pc4ca20 (without source)
pbcdllmtcibd001                     B40Pc4ca20 (without source)
pbcdllmtcibd002                     B40Pc4ca20 (without source)
pbcdllmtcmcs003                     B40Pc4ca20 (without source)
pbcdllmtcppl101                     B40Pc4ca20 (without source)
pbcdllmtdpcg030                     B40Pc4ca20 (without source)
pbcdllmtdpur401                     B40Pc4ca20 (without source)
pbcdllmtdsls401                     B40Pc4ca20 (without source)
pbcdllmtdsmi200                     B40Pc4ca20 (without source)
pbcdllmtdsta200                     B40Pc4ca20 (without source)
pbcdllmtfacp240                     B40Pc4ca20 (without source)
pbcdllmtfacp250                     B40Pc4ca20 (without source)
pbcdllmtfacr005                     B40Pc4ca20 (without source)
pbcdllmtffam500                     B40Pc4ca20 (without source)
pbcdllmtffam800                     B40Pc4ca20 (without source)
pbcdllmtffbs005                     B40Pc4ca20 (without source)
pbcdllmtffst120                     B40Pc4ca20 (without source)
pbcdllmtfgld008                     B40Pc4ca20 (without source)
pbcdllmticst300                     B40Pc4ca20 (without source)
pbcdllmtsctm120                     B40Pc4ca20 (without source)
pbcdllmtsctm300                     B40Pc4ca20 (without source)
pbcdllmtssoc000                     B40Pc4ca20 (without source)
pbcdllmtssoc200                     B40Pc4ca20 (without source)
pbcdllmtssoc220                     B40Pc4ca20 (without source)
pbcdllmtssoc850                     B40Pc4ca20 (without source)
pbcdllmtssoc860                     B40Pc4ca20 (without source)
pbcdllmwhinh200                     B40Pc4ca20 (without source)
pbcdllmwhltc300                     B40Pc4ca20 (without source)
pbcdllmwhwmd300                     B40Pc4ca20 (without source)
pbcintdll0000                       B40Pc4ca20 (without source)
pbcmttdll0004                       B40Pc4ca20 (without source)
pbcscp003                           B40Pc4ca20 (without source)
pbcstc000                           B40Pc4ca20 (without source)
pbcstf000                           B40Pc4ca20 (without source)
pbcstf0100                          B40Pc4ca20 (without source)
pbcstf0113                          B40Pc4ca20 (without source)
pbcstf013                           B40Pc4ca20 (without source)
pbcstfdll1001                       B40Pc4ca20 (without source)
pbcsts005                           B40Pc4ca20 (without source)
pbcsts006                           B40Pc4ca20 (without source)
pbcsts007                           B40Pc4ca20 (without source)
pbcsts0107                          B40Pc4ca20 (without source)
pbcstsdll1001                       B40Pc4ca20 (without source)
pbcswh007                           B40Pc4ca20 (without source)
fbcstf0100m00012                    B40Pc4ca20
fbcstf0113m00012                    B40Pc4ca20
fbcsts0107m00012                    B40Pc4ca20
fbcswh0107m00012                    B40Pc4ca20
cbcstc00004                         B40Pc4ca20
bbcswh0001                          B40Pc4ca20 (with source)
bbcswh0007                          B40Pc4ca20 (with source)
bbcswh0008                          B40Pc4ca20 (with source)
mbcstf0000100112                    B40Pc4ca20
mbcsts0000100112                    B40Pc4ca20
mbcsts0000200112                    B40Pc4ca20
mbcsts0000300112                    B40Pc4ca20
obcdllfbcttf006                     B40Pc4ca20
obcdllfcisli100                     B40Pc4ca20
obcdllfcisli120                     B40Pc4ca20
obcdllfcisli200                     B40Pc4ca20
obcdllfcisli201                     B40Pc4ca20
obcdllfcprpd400                     B40Pc4ca20
obcdllfcprpd420                     B40Pc4ca20
obcdllfecedi702                     B40Pc4ca20
obcdllffmfmd100                     B40Pc4ca20
obcdllffmfrc000                     B40Pc4ca20
obcdllffmlbd000                     B40Pc4ca20
obcdllfqmptc101                     B40Pc4ca20
obcdllfqmptc110                     B40Pc4ca20
obcdllfqmptc115                     B40Pc4ca20
obcdllfqmptc230                     B40Pc4ca20
obcdllfqmptc301                     B40Pc4ca20
obcdllfqmptc302                     B40Pc4ca20
obcdllfqmptc305                     B40Pc4ca20
obcdllftccom000                     B40Pc4ca20
obcdllftccom700                     B40Pc4ca20
obcdllftccom710                     B40Pc4ca20
obcdllftccom999                     B40Pc4ca20
obcdllftcemm000                     B40Pc4ca20
obcdllftcmcs000                     B40Pc4ca20
obcdllftcmcs001                     B40Pc4ca20
obcdllftcmcs055                     B40Pc4ca20
obcdllftcmcs120                     B40Pc4ca20
obcdllftcmcs121                     B40Pc4ca20
obcdllftcmcs122                     B40Pc4ca20
obcdllftcmcs123                     B40Pc4ca20
obcdllftcmcs138                     B40Pc4ca20
obcdllftctax000                     B40Pc4ca20
obcdllftctax601                     B40Pc4ca20
obcdllftctax603                     B40Pc4ca20
obcdllftdipu010                     B40Pc4ca20
obcdllftdpcg000                     B40Pc4ca20
obcdllftdpur000                     B40Pc4ca20
obcdllftdpur012                     B40Pc4ca20
obcdllftdpur400                     B40Pc4ca20
obcdllftdpur451                     B40Pc4ca20
obcdllftdsls000                     B40Pc4ca20
obcdllftdsls012                     B40Pc4ca20
obcdllftdsls027                     B40Pc4ca20
obcdllftdsls028                     B40Pc4ca20
obcdllftdsls060                     B40Pc4ca20
obcdllftdsls094                     B40Pc4ca20
obcdllftdsls301                     B40Pc4ca20
obcdllftdsls351                     B40Pc4ca20
obcdllftdsls400                     B40Pc4ca20
obcdllftdsls450                     B40Pc4ca20
obcdllftdsls451                     B40Pc4ca20
obcdllftdsmi002                     B40Pc4ca20
obcdllftdsmi003                     B40Pc4ca20
obcdllftdsmi040                     B40Pc4ca20
obcdllftdsmi054                     B40Pc4ca20
obcdllftdsmi101                     B40Pc4ca20
obcdllftdsmi110                     B40Pc4ca20
obcdllftdsmi111                     B40Pc4ca20
obcdllftdsmi121                     B40Pc4ca20
obcdllftdsmi201                     B40Pc4ca20
obcdllftdsmi206                     B40Pc4ca20
obcdllftdsmi210                     B40Pc4ca20
obcdllftfacp002                     B40Pc4ca20
obcdllftfacp200                     B40Pc4ca20
obcdllftfacr200                     B40Pc4ca20
obcdllftfcmg000                     B40Pc4ca20
obcdllftfcmg006                     B40Pc4ca20
obcdllftffam000                     B40Pc4ca20
obcdllftffam010                     B40Pc4ca20
obcdllftffam100                     B40Pc4ca20
obcdllftffam110                     B40Pc4ca20
obcdllftffam200                     B40Pc4ca20
obcdllftffam520                     B40Pc4ca20
obcdllftffam650                     B40Pc4ca20
obcdllftffam710                     B40Pc4ca20
obcdllftffam775                     B40Pc4ca20
obcdllftffst011                     B40Pc4ca20
obcdllftfgld004                     B40Pc4ca20
obcdllftfgld107                     B40Pc4ca20
obcdllftfgld110                     B40Pc4ca20
obcdllftiedm000                     B40Pc4ca20
obcdllftiedm010                     B40Pc4ca20
obcdllftiedm120                     B40Pc4ca20
obcdllftipcf000                     B40Pc4ca20
obcdllftipcf320                     B40Pc4ca20
obcdllftipcs030                     B40Pc4ca20
obcdllftipcs400                     B40Pc4ca20
obcdllftipcs420                     B40Pc4ca20
obcdllftirou000                     B40Pc4ca20
obcdllftirou102                     B40Pc4ca20
obcdllftisfc000                     B40Pc4ca20
obcdllftisfc001                     B40Pc4ca20
obcdllftisfc010                     B40Pc4ca20
obcdllftppdm600                     B40Pc4ca20
obcdllftpppc000                     B40Pc4ca20
obcdllftpppc210                     B40Pc4ca20
obcdllftppss200                     B40Pc4ca20
obcdllftscfg210                     B40Pc4ca20
obcdllftsctm100                     B40Pc4ca20
obcdllftsctm110                     B40Pc4ca20
obcdllftsctm400                     B40Pc4ca20
obcdllfwhinh000                     B40Pc4ca20
obcdllfwhinh010                     B40Pc4ca20
obcdllfwhinr130                     B40Pc4ca20
obcdllfwhwmd000                     B40Pc4ca20
obcdllmcisli205                     B40Pc4ca20
obcdllmcisli220                     B40Pc4ca20
obcdllmcisli230                     B40Pc4ca20
obcdllmcisli240                     B40Pc4ca20
obcdllmcisli250                     B40Pc4ca20
obcdllmcisli260                     B40Pc4ca20
obcdllmcprpd100                     B40Pc4ca20
obcdllmcprrp100                     B40Pc4ca20
obcdllmfmfoc200                     B40Pc4ca20
obcdllmqmptc100                     B40Pc4ca20
obcdllmtccom100                     B40Pc4ca20
obcdllmtccom140                     B40Pc4ca20
obcdllmtcibd001                     B40Pc4ca20
obcdllmtcibd002                     B40Pc4ca20
obcdllmtcmcs003                     B40Pc4ca20
obcdllmtcppl101                     B40Pc4ca20
obcdllmtdpcg030                     B40Pc4ca20
obcdllmtdpur401                     B40Pc4ca20
obcdllmtdsls401                     B40Pc4ca20
obcdllmtdsmi200                     B40Pc4ca20
obcdllmtdsta200                     B40Pc4ca20
obcdllmtfacp240                     B40Pc4ca20
obcdllmtfacp250                     B40Pc4ca20
obcdllmtfacr005                     B40Pc4ca20
obcdllmtffam500                     B40Pc4ca20
obcdllmtffam800                     B40Pc4ca20
obcdllmtffbs005                     B40Pc4ca20
obcdllmtffst120                     B40Pc4ca20
obcdllmtfgld008                     B40Pc4ca20
obcdllmticst300                     B40Pc4ca20
obcdllmtsctm120                     B40Pc4ca20
obcdllmtsctm300                     B40Pc4ca20
obcdllmtssoc000                     B40Pc4ca20
obcdllmtssoc200                     B40Pc4ca20
obcdllmtssoc220                     B40Pc4ca20
obcdllmtssoc850                     B40Pc4ca20
obcdllmtssoc860                     B40Pc4ca20
obcdllmwhinh200                     B40Pc4ca20
obcdllmwhltc300                     B40Pc4ca20
obcdllmwhwmd300                     B40Pc4ca20
obcintdll0000                       B40Pc4ca20
obcmttdll0004                       B40Pc4ca20
obcscp003                           B40Pc4ca20
obcstc000                           B40Pc4ca20
obcstf000                           B40Pc4ca20
obcstf0100                          B40Pc4ca20
obcstf0113                          B40Pc4ca20
obcstf013                           B40Pc4ca20
obcstfdll1001                       B40Pc4ca20
obcsts005                           B40Pc4ca20
obcsts006                           B40Pc4ca20
obcsts007                           B40Pc4ca20
obcsts0107                          B40Pc4ca20
obcstsdll1001                       B40Pc4ca20
obcswh007                           B40Pc4ca20
lbcbcgen.slash                      B40Pc4ca20
lbcbcstf000.dlcd                    B40Pc4ca20
lbcbcstf000.dloc                    B40Pc4ca20
lbcbcstf013.anbr                    B40Pc4ca20
lbcbcstf013.dkey                    B40Pc4ca20
lbcbcstf013.lkey                    B40Pc4ca20
lbcbcstf013.loca                    B40Pc4ca20
lbcbcsts007.ccom                    B40Pc4ca20
lbcbcsts007.ccon                    B40Pc4ca20
lbcbcsts007.csco                    B40Pc4ca20
lbcbcswh007.apsq                    B40Pc4ca20
lbcbcswh007.orno                    B40Pc4ca20
lbcbcswh007.pono                    B40Pc4ca20
lbcbcswh007.serb                    B40Pc4ca20
lbcbcswh007.serc                    B40Pc4ca20
lbcbcswh007.srnb                    B40Pc4ca20
Fbcstf0100m00012                    B40Pc4ca20
Fbcstf0113m00012                    B40Pc4ca20
Fbcsts0107m00012                    B40Pc4ca20
Fbcswh0107m00012                    B40Pc4ca20
Mbcstf0000100112                    B40Pc4ca20
Mbcsts0000100112                    B40Pc4ca20
Mbcsts0000200112                    B40Pc4ca20
Mbcsts0000300112                    B40Pc4ca20
hbcFCstf000.dlcd                    B40Pc4ca20
hbcFCstf000.dloc                    B40Pc4ca20
hbcFCstf000.losd                    B40Pc4ca20
hbcFCstf000.rcre                    B40Pc4ca20
hbcFCstf013.anbr                    B40Pc4ca20
hbcFCstf013.dkey                    B40Pc4ca20
hbcFCstf013.lkey                    B40Pc4ca20
hbcFCstf013.loca                    B40Pc4ca20
hbcFCsts007.ccon                    B40Pc4ca20
hbcFCsts007.csco                    B40Pc4ca20
hbcFCsts007.lmdt                    B40Pc4ca20
hbcFCsts007.lmtm                    B40Pc4ca20
hbcFCswh007.apno                    B40Pc4ca20
hbcFCswh007.apsq                    B40Pc4ca20
hbcFCswh007.orgn                    B40Pc4ca20
hbcFDstf000.dloc                    B40Pc4ca20
hbcFIstf000.dlcd                    B40Pc4ca20
hbcFIstf000.dloc                    B40Pc4ca20
hbcFIstf013.anbr                    B40Pc4ca20
hbcFIstf013.dkey                    B40Pc4ca20
hbcFIstf013.lkey                    B40Pc4ca20
hbcFIstf013.loca                    B40Pc4ca20
hbcSEstf0109m000                    B40Pc4ca20
hbcSEstf0113m000                    B40Pc4ca20
hbcSEsts0105m000                    B40Pc4ca20
hbcSEsts0107m000                    B40Pc4ca20
